@@ -32,6 +32,7 @@ class GroupMember(models.Model, MojoModel):
     class RestMeta:
         VIEW_PERMS = ["view_members", "view_groups", "manage_groups", "manage_group"]
         SAVE_PERMS = ["manage_groups", "manage_group"]
+        SEARCH_FIELDS = ["user__username", "user__email", "user__display_name"]
         CREATED_BY_OWNER_FIELD = 'created_by'  # we do this to protect user
         LIST_DEFAULT_FILTERS = {
             "is_active": True
@@ -114,7 +115,11 @@ class GroupMember(models.Model, MojoModel):
 
     def add_permission(self, perm_key, value=True):
         """Dynamically add a permission."""
-        self.permissions[perm_key] = value
+        if isinstance(perm_key, (list, set)):
+            for pk in perm_key:
+                self.add_permission(pk, value)
+        else:
+            self.permissions[perm_key] = value
         self.save()
 
     def remove_permission(self, perm_key):
